<no title> — PAK UNIOR v1.2 documentation

Class PlotDynamicUpdate, use for update data plots and initialize Unior module

class `PlotDynamicUpdate.` `PlotDynamicUpdate`

  Bases: `object`

  Class for dynamic updating plot

  `activate_line_on_`(data, value, values=[0, 1])

    Set up line of barier of alfa ritms

  static `curve_on`(data)

    Curved on array of smth values

  `on_running`(source_list)

    Update data (with the new _and_ the old points)